function foo(e__2) {
    e__0: {
        try {} catch (e1__3) {
            o = null;
            break e__0;
        }
    }
}
